# Moxa Interface

This project was created to interface with the 
[Moxa nport-5600dt series](https://www.moxa.com/en/products/industrial-edge-connectivity/serial-device-servers/general-device-servers/nport-5600-dt-series)
of serial device servers, although it may work with other models too.

This has been developed purely with my own use case in mind, but may serve as a useful starting point for other 
projects.

I may well develop documentation in the future, but for now, just use the code as documentation.